@@ -106,8 +106,8 @@ protected:
     virtual void dragEnterEvent(QDragEnterEvent *event);
 
     /**
-     * For dropping data into an empty signal 
-     * @see Qt XDND documentation 
+     * For dropping data into an empty signal
+     * @see Qt XDND documentation
      */
     virtual void dropEvent(QDropEvent *event);
 
@@ -145,6 +145,12 @@ public slots:
      */
     void setOffset(sample_index_t new_offset);
 
+    /**
+     * Scrolls the display so that the given position gets visible,
+     * centered within the display if possible.
+     */
+    void scrollTo(sample_index_t pos);
+
     /**
      * sets a new zoom factor [samples/pixel], does not refresh the screen
      * @param new_zoom new zoom value, will be internally limited
@@ -193,7 +199,7 @@ private slots:
      * @see SignalManager::sigTrackInserted
      * @internal
      */
-    void slotTrackInserted(unsigned int index, Track *track);
+    void slotTrackInserted(unsigned int index, Kwave::Track *track);
 
     /**
      * Called if a track has been deleted. Updates the display by
@@ -204,9 +210,6 @@ private slots:
      */
     void slotTrackDeleted(unsigned int index);
 
-    /** updates the scrollbar */
-    void updateViewInfo(sample_index_t, sample_index_t, sample_index_t);
-
     /**
      * Connected to the vertical scrollbar and called if the value
      * has changed so that the signal display and the channel
@@ -231,6 +234,11 @@ signals:
     /** forward a sigCommand to the next layer */
     void sigCommand(const QString &command);
 
+    /** emitted when the visible range has changed */
+    void sigVisibleRangeChanged(sample_index_t offset,
+                                sample_index_t visible,
+                                sample_index_t total);
+
 private:
 
     /**
@@ -263,15 +271,16 @@ private:
      * into the current window.
      * @return zoom value [samples/pixel]
      */
-    double fullZoom();
+    double fullZoom() const;
 
     /**
      * Fixes the zoom and the offset of the display so that no non-existing
      * samples (index < 0 or index >= length) have to be displayed and the
      * current display window of the signal fits into the screen.
-     * @return true if either offset or zoom has changed, otherwise false
+     * @param zoom new zoom value [samples/pixel]
+     * @param offset new offset value [samples]
      */
-    bool fixZoomAndOffset();
+    void fixZoomAndOffset(double zoom, sample_index_t offset);
 
     /**
      * add a new label
