@@ -70,48 +70,45 @@
 #include "KwaveApp.h"
 #include "KwaveSplash.h"
 #include "MainWidget.h"
+#include "PlayerToolBar.h"
 #include "TopWidget.h"
 
-#include "pics/playback_loop.xpm"
-#include "pics/playback_pause.xpm"
-#include "pics/playback_pause2.xpm"
-#include "pics/playback_start.xpm"
-#include "pics/playback_stop.xpm"
-
-#include "toolbar/zoomrange.xpm"
-#include "toolbar/zoomin.xpm"
-#include "toolbar/zoomout.xpm"
-#include "toolbar/zoomnormal.xpm"
-#include "toolbar/zoomall.xpm"
-
 /**
  * useful macro for command parsing
  */
 #define CASE_COMMAND(x) } else if (parser.command() == x) {
 
-//***************************************************************************
-KToolBar *TopWidget::toolBar(const QString &name)
-{
-    KToolBar *toolbar = KMainWindow::toolBar(name);
-    if (!toolbar) return 0;
-    toolbar->setFloatable(false);
-    toolbar->setToolButtonStyle(Qt::ToolButtonIconOnly);
-    return toolbar;
-}
+/** toolbar name: file operations */
+#define TOOLBAR_FILE        "MainWidget File"
+
+/** toolbar name: edit operations */
+#define TOOLBAR_EDIT        "MainWidget Edit"
+
+/** toolbar name: record and playback */
+#define TOOLBAR_RECORD_PLAY "MainWidget Record/Playback"
+
+/** toolbar name: zoom controls */
+#define TOOLBAR_ZOOM        "MainWidget Zoom"
+
+/** role value for entries in the zoom combo box, "predefined" flag (bool) */
+#define ZOOM_DATA_PREDEFINED (Qt::UserRole + 0)
+
+/** role value for entries in the zoom combo box, "time" in ms (double) */
+#define ZOOM_DATA_TIME       (Qt::UserRole + 1)
+
+/** returns the number of elements of an array */
+#define ELEMENTS_OF(__x__) (sizeof(__x__) / sizeof(__x__[0]))
 
 //***************************************************************************
 //***************************************************************************
 TopWidget::TopWidget(Kwave::ApplicationContext &context)
-    :KMainWindow(), m_context(context), m_zoom_factors(),
-     m_main_widget(0), m_zoomselect(0), m_menu_manager(0), m_pause_timer(0),
-     m_blink_on(false), m_action_undo(0), m_action_redo(0), m_action_play(0),
-     m_action_loop(0), m_action_pause(0),m_action_stop(0),
+    :KMainWindow(), m_context(context),
+     m_main_widget(0), m_toolbar_record_playback(0), m_zoomselect(0),
+     m_menu_manager(0), m_action_undo(0), m_action_redo(0),
      m_action_zoomselection(0), m_action_zoomin(0), m_action_zoomout(0),
      m_action_zoomnormal(0), m_action_zoomall(0), m_action_zoomselect(0),
      m_lbl_status_size(0), m_lbl_status_mode(0), m_lbl_status_cursor(0)
 {
-    KIconLoader icon_loader;
-    
     // status bar items
     KStatusBar *status_bar = statusBar();
     Q_ASSERT(status_bar);
@@ -141,12 +138,16 @@ TopWidget::TopWidget(Kwave::ApplicationContext &context)
     status_bar->addWidget(m_lbl_status_size);
     m_lbl_status_size->setSizePolicy(policy);
     m_lbl_status_size->setFrameStyle(frame_style);
+
+    // direct all kind of focus to this window per default
+    setFocusPolicy(Qt::WheelFocus);
 }
 
 //***************************************************************************
 bool TopWidget::init()
 {
     KIconLoader icon_loader;
+    const int max_s = KIconLoader::SizeEnormous;
 
     showInSplashSreen(i18n("Loading main menu..."));
     KMenuBar *menubar = menuBar();
@@ -186,6 +187,9 @@ bool TopWidget::init()
     connect(&m_context.signalManager()->playbackController(),
             SIGNAL(sigPlaybackPos(sample_index_t)),
             this, SLOT(updatePlaybackPos(sample_index_t)));
+    connect(&m_context.signalManager()->playbackController(),
+            SIGNAL(sigSeekDone(sample_index_t)),
+            m_main_widget, SLOT(scrollTo(sample_index_t)));
 
     // connect the sigCommand signal to ourself, this is needed
     // for the plugins
@@ -195,7 +199,7 @@ bool TopWidget::init()
     // --- set up the toolbar ---
 
     showInSplashSreen(i18n("Initializing toolbar..."));
-    KToolBar *toolbar_file = toolBar("MainWidget File");
+    KToolBar *toolbar_file = toolBar(TOOLBAR_FILE);
     Q_ASSERT(toolbar_file);
     if (!toolbar_file) return false;
 
@@ -218,7 +222,7 @@ bool TopWidget::init()
 
     // --- edit, cut&paste ---
 
-    KToolBar *toolbar_edit = toolBar("MainWidget Edit");
+    KToolBar *toolbar_edit = toolBar(TOOLBAR_EDIT);
     Q_ASSERT(toolbar_edit);
     if (!toolbar_edit) return false;
 
@@ -234,17 +238,17 @@ bool TopWidget::init()
 
     toolbar_edit->addAction(
 	icon_loader.loadIcon("edit-cut", KIconLoader::Toolbar),
-	i18n("Cut the current selection and move it to the clipboard"),
+	i18n("Cut"),
 	this, SLOT(toolbarEditCut()));
 
     toolbar_edit->addAction(
 	icon_loader.loadIcon("edit-copy", KIconLoader::Toolbar),
-	i18n("Copy the current selection to the clipboard"),
+	i18n("Copy"),
 	this, SLOT(toolbarEditCopy()));
 
     QAction *btPaste = toolbar_edit->addAction(
 	icon_loader.loadIcon("edit-paste", KIconLoader::Toolbar),
-	i18n("Insert the content of clipboard"),
+	i18n("Insert"),
 	this, SLOT(toolbarEditPaste()));
     btPaste->setEnabled(!ClipBoard::instance().isEmpty());
     connect(&ClipBoard::instance(), SIGNAL(clipboardChanged(bool)),
@@ -252,12 +256,12 @@ bool TopWidget::init()
 
     toolbar_edit->addAction(
 	icon_loader.loadIcon("draw-eraser", KIconLoader::Toolbar),
-	i18n("Mute the current selection"),
+	i18n("Mute selection"),
 	this, SLOT(toolbarEditErase()));
 
     toolbar_edit->addAction(
 	icon_loader.loadIcon("edit-delete", KIconLoader::Toolbar),
-	i18n("Delete the current selection"),
+	i18n("Delete selection"),
 	this, SLOT(toolbarEditDelete()));
 
 //                  Zoom
@@ -267,73 +271,51 @@ bool TopWidget::init()
 
 //                  Help
 
-    // --- playback controls ---
+    // --- record/playback controls ---
 
-    QObject *playback = &(m_context.signalManager()->playbackController());
-    KToolBar *toolbar_playback = toolBar("MainWidget Playback");
-    Q_ASSERT(toolbar_playback);
-    if (!toolbar_playback) return false;
+    m_toolbar_record_playback = new Kwave::PlayerToolBar(
+	this, TOOLBAR_RECORD_PLAY,
+	m_context.signalManager()->playbackController(),
+	*m_menu_manager);
 
-    m_action_play = toolbar_playback->addAction(
-	QPixmap(xpm_play),
-	i18n("Start playback"),
-	playback, SLOT(playbackStart()));
+    Q_ASSERT(m_toolbar_record_playback);
+    if (!m_toolbar_record_playback) return false;
 
-    m_action_loop = toolbar_playback->addAction(
-	QPixmap(xpm_loop),
-	i18n("Start playback and loop"),
-	playback, SLOT(playbackLoop()));
-
-    m_action_pause = toolbar_playback->addAction(
-	QPixmap(xpm_pause),
-	i18n("Pause playback"),
-	this, SLOT(pausePressed()));
-
-    m_action_stop = toolbar_playback->addAction(
-	QPixmap(xpm_stop),
-	i18n("Stop playback or loop"),
-	playback, SLOT(playbackStop()));
+    connect(m_toolbar_record_playback, SIGNAL(sigCommand(const QString &)),
+            this,                    SLOT(executeCommand(const QString &)));
+    connect(m_main_widget, SIGNAL(sigVisibleRangeChanged(sample_index_t,
+	    sample_index_t, sample_index_t)),
+	    m_toolbar_record_playback, SLOT(visibleRangeChanged(sample_index_t,
+	    sample_index_t, sample_index_t)) );
 
     // --- zoom controls ---
-    m_zoom_factors.append(ZoomFactor(i18n("%1 ms",   1),            1L));
-    m_zoom_factors.append(ZoomFactor(i18n("%1 ms",  10),           10L));
-    m_zoom_factors.append(ZoomFactor(i18n("%1 ms", 100),          100L));
-    m_zoom_factors.append(ZoomFactor(i18n("%1 sec",  1),         1000L));
-    m_zoom_factors.append(ZoomFactor(i18n("%1 sec", 10),     10L*1000L));
-    m_zoom_factors.append(ZoomFactor(i18n("%1 sec", 30),     30L*1000L));
-    m_zoom_factors.append(ZoomFactor(i18n("%1 min",  1),  1L*60L*1000L));
-    m_zoom_factors.append(ZoomFactor(i18n("%1 min",  3),  3L*60L*1000L));
-    m_zoom_factors.append(ZoomFactor(i18n("%1 min",  5),  5L*60L*1000L));
-    m_zoom_factors.append(ZoomFactor(i18n("%1 min", 10), 10L*60L*1000L));
-    m_zoom_factors.append(ZoomFactor(i18n("%1 min", 30), 30L*60L*1000L));
-    m_zoom_factors.append(ZoomFactor(i18n("%1 min", 60), 60L*60L*1000L));
 
-    KToolBar *toolbar_zoom = toolBar("MainWidget Zoom");
+    KToolBar *toolbar_zoom = toolBar(TOOLBAR_ZOOM);
     Q_ASSERT(toolbar_zoom);
     if (!toolbar_zoom) return false;
 
     m_action_zoomselection = toolbar_zoom->addAction(
-	QPixmap(xpm_zoomrange),
+	icon_loader.loadIcon("kwave_viewmag", KIconLoader::Toolbar, max_s),
 	i18n("Zoom to selection"),
 	m_main_widget, SLOT(zoomSelection()));
 
     m_action_zoomin = toolbar_zoom->addAction(
-	QPixmap(xpm_zoomin),
+	icon_loader.loadIcon("kwave_zoom_in", KIconLoader::Toolbar, max_s),
 	i18n("Zoom in"),
 	m_main_widget, SLOT(zoomIn()));
 
     m_action_zoomout = toolbar_zoom->addAction(
-	QPixmap(xpm_zoomout),
+	icon_loader.loadIcon("kwave_zoom_out", KIconLoader::Toolbar, max_s),
 	i18n("Zoom out"),
 	m_main_widget, SLOT(zoomOut()));
 
     m_action_zoomnormal = toolbar_zoom->addAction(
-	QPixmap(xpm_zoomnormal),
+	icon_loader.loadIcon("kwave_zoom_original", KIconLoader::Toolbar, max_s),
 	i18n("Zoom to 100%"),
 	m_main_widget, SLOT(zoomNormal()));
 
     m_action_zoomall = toolbar_zoom->addAction(
-	QPixmap(xpm_zoomall),
+	icon_loader.loadIcon("kwave_viewmagfit", KIconLoader::Toolbar, max_s),
 	i18n("Zoom to all"),
 	m_main_widget, SLOT(zoomAll()));
 
@@ -344,8 +326,33 @@ bool TopWidget::init()
     m_zoomselect->setToolTip(i18n("Select zoom factor"));
     m_zoomselect->setInsertPolicy(QComboBox::InsertAtTop);
     m_zoomselect->setEditable(false);
-    foreach (ZoomFactor zoom, m_zoom_factors)
-	m_zoomselect->addItem(zoom.first);
+
+    /** Initialized list of zoom factors */
+    struct {
+	const QString text;
+	unsigned int ms;
+    } zoom_factors[] = {
+	{ i18n("%1 ms",   1),            1L},
+	{ i18n("%1 ms",  10),           10L},
+	{ i18n("%1 ms", 100),          100L},
+	{ i18n("%1 sec",  1),         1000L},
+	{ i18n("%1 sec", 10),     10L*1000L},
+	{ i18n("%1 sec", 30),     30L*1000L},
+	{ i18n("%1 min",  1),  1L*60L*1000L},
+	{ i18n("%1 min",  3),  3L*60L*1000L},
+	{ i18n("%1 min",  5),  5L*60L*1000L},
+	{ i18n("%1 min", 10), 10L*60L*1000L},
+	{ i18n("%1 min", 30), 30L*60L*1000L},
+	{ i18n("%1 min", 60), 60L*60L*1000L},
+    };
+
+    for (unsigned int i = 0; i < ELEMENTS_OF(zoom_factors); i++) {
+	m_zoomselect->addItem(zoom_factors[i].text);
+	int index = m_zoomselect->count() - 1;
+	unsigned int time = zoom_factors[i].ms;
+	m_zoomselect->setItemData(index, QVariant(true), ZOOM_DATA_PREDEFINED);
+	m_zoomselect->setItemData(index, QVariant(time), ZOOM_DATA_TIME);
+    }
 
     m_action_zoomselect = toolbar_zoom->addWidget(m_zoomselect);
     connect(m_zoomselect, SIGNAL(activated(int)),
@@ -353,15 +360,8 @@ bool TopWidget::init()
     connect(m_main_widget, SIGNAL(sigZoomChanged(double)),
             this, SLOT(setZoomInfo(double)));
     int h = m_zoomselect->sizeHint().height();
-    m_zoomselect->setMinimumWidth(h*5);
-
-    // connect the playback controller
-    connect(playback, SIGNAL(sigPlaybackStarted()),
-            this,     SLOT(updatePlaybackControls()));
-    connect(playback, SIGNAL(sigPlaybackPaused()),
-            this,     SLOT(playbackPaused()));
-    connect(playback, SIGNAL(sigPlaybackStopped()),
-            this,     SLOT(updatePlaybackControls()));
+    m_zoomselect->setMinimumWidth(h * 5);
+    m_zoomselect->setFocusPolicy(Qt::FocusPolicy(Qt::ClickFocus | Qt::TabFocus));
 
     // connect the signal manager
     SignalManager *signal_manager = m_context.signalManager();
@@ -376,8 +376,11 @@ bool TopWidget::init()
             this,           SLOT(modifiedChanged(bool)));
     connect(signal_manager, SIGNAL(sigMetaDataChanged(Kwave::MetaDataList)),
             this,           SLOT(metaDataChanged(Kwave::MetaDataList)));
+    connect(signal_manager, SIGNAL(sigMetaDataChanged(Kwave::MetaDataList)),
+            m_toolbar_record_playback,
+                            SLOT(metaDataChanged(Kwave::MetaDataList)));
 
-    // create the plugin manager instance
+    // connect the plugin manager
     Kwave::PluginManager *plugin_manager = m_context.pluginManager();
     connect(plugin_manager, SIGNAL(sigCommand(const QString &)),
             this,           SLOT(executeCommand(const QString &)));
@@ -431,18 +434,23 @@ bool TopWidget::init()
     // workaround for KDE4: detect first startup and set all toolbars
     // to "only symbols" mode
     KConfigGroup cfg = KGlobal::config()->group("MainWindow");
-    QString magic = "1";
+    QString magic = "2";
     if (cfg.readEntry("toolbars") != magic) {
-	qDebug("FIRST RUN => forcing toolbars to 'symbols only' mode");
-	foreach(KToolBar *bar, toolBars()) {
-	    bar->setToolButtonStyle(Qt::ToolButtonIconOnly);
-	    bar->update();
-	    bar->hide();
-	    bar->show();
-	}
+	qDebug("toolbar layout changed => resetting toolbars to defaults");
+
+	// unlock all toolbars
+	KToolBar::setToolBarsLocked(false);
+
+	// reset all toolbars to default layout
+	resetToolbarToDefaults();
+
 	cfg.writeEntry("toolbars", magic);
     }
 
+    // make sure we have the focus, not the zoom combo box
+    m_zoomselect->clearFocus();
+    setFocus();
+
     return true;
 }
 
@@ -453,9 +461,6 @@ TopWidget::~TopWidget()
     // close the current file (no matter what the user wants)
     closeFile();
 
-    if (m_pause_timer) delete m_pause_timer;
-    m_pause_timer = 0;
-
     if (m_main_widget) delete m_main_widget;
     m_main_widget = 0;
 
@@ -515,12 +520,22 @@ int TopWidget::executeCommand(const QString &line)
     if (parser.command() == "plugin") use_recorder = false;
 
     // playback commands are always possible
-    if (parser.command() == "playback") {
-	return executePlaybackCommand(parser.firstParam()) ? 0 : -1;
+    if ( (parser.command() == "playback") && (m_toolbar_record_playback) )
+    {
+	return m_toolbar_record_playback->executeCommand(parser.firstParam());
     }
 
+    // let through all commands that handle zoom/view or playback like fwd/rew
+    bool allow_always =
+	parser.command().startsWith("view:") ||
+	parser.command().startsWith("playback:") ||
+	parser.command().startsWith("select_track:") ||
+	(parser.command() == "close") ||
+	(parser.command() == "quit")
+	;
+
     // all others only if no plugin is currently running
-    if (plugin_manager && plugin_manager->onePluginRunning())
+    if (!allow_always && plugin_manager && plugin_manager->onePluginRunning())
     {
 	qWarning("TopWidget::executeCommand('%s') - currently not possible, "\
 		 "a plugin is running :-(",
@@ -610,6 +625,13 @@ int TopWidget::executeCommand(const QString &line)
 	result = saveFileAs(true);
     CASE_COMMAND("quit")
 	result = (close()) ? 0 : -1;
+    CASE_COMMAND("reset_toolbars")
+	if ((result = (Kwave::MessageBox::questionYesNo(this,
+	    i18n("Reset the toolbar to default settings?"))
+	    == KMessageBox::Yes) ? 1 : 0))
+	{
+	    resetToolbarToDefaults();
+	}
     } else {
 	// try to forward the command to the main widget
 	Q_ASSERT(m_main_widget);
@@ -643,31 +665,6 @@ int TopWidget::loadBatch(const KUrl &url)
     return result;
 }
 
-//***************************************************************************
-int TopWidget::executePlaybackCommand(const QString &command)
-{
-    SignalManager *signal_manager = m_context.signalManager();
-    Q_ASSERT(signal_manager);
-    if (!signal_manager) return -1;
-
-    PlaybackController &controller =
-	m_context.signalManager()->playbackController();
-    if (command == "start") {
-	controller.playbackStart();
-    } else if (command == "loop") {
-	controller.playbackLoop();
-    } else if (command == "stop") {
-	controller.playbackStop();
-    } else if (command == "pause") {
-	pausePressed();
-    } else if (command == "continue") {
-	pausePressed();
-    } else {
-	return -EINVAL;
-    }
-    return 0;
-}
-
 //***************************************************************************
 int TopWidget::parseCommands(QTextStream &stream)
 {
@@ -720,7 +717,7 @@ int TopWidget::parseCommands(QTextStream &stream)
 	// the "msgbox" command (useful for debugging)
 	if (parser.command() == "msgbox") {
 	    QApplication::restoreOverrideCursor();
-	    result = (Kwave::MessageBox::questionYesNo(this, 
+	    result = (Kwave::MessageBox::questionYesNo(this,
 		parser.firstParam()) == KMessageBox::Yes) ? 0 : 1;
 	    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 	    continue;
@@ -736,7 +733,7 @@ int TopWidget::parseCommands(QTextStream &stream)
 
 	// synchronize after the command
 	if (m_context.pluginManager()) m_context.pluginManager()->sync();
-	
+
 	// special handling of the "quit" command
 	if (parser.command() == "quit") {
 	    break;
@@ -761,10 +758,10 @@ int TopWidget::revert()
 //***************************************************************************
 bool TopWidget::closeFile()
 {
-    SignalManager *signal_manager = m_context.signalManager();
+    SignalManager        *signal_manager = m_context.signalManager();
+    Kwave::PluginManager *plugin_manager = m_context.pluginManager();
 
-    if (m_context.pluginManager() &&
-	m_context.pluginManager()->onePluginRunning())
+    if (plugin_manager && !plugin_manager->canClose())
     {
 	qWarning("TopWidget::closeFile() - currently not possible, "\
 	         "a plugin is running :-(");
@@ -784,13 +781,11 @@ bool TopWidget::closeFile()
     }
 
     // close all plugins that still might use the current signal
-    if (m_context.pluginManager()) {
-	m_context.pluginManager()->sync();
-	m_context.pluginManager()->signalClosed();
+    if (plugin_manager) {
+	plugin_manager->stopAllPlugins();
+	plugin_manager->signalClosed();
     }
 
-//     Q_ASSERT(m_main_widget);
-//     if (m_main_widget) m_main_widget->closeSignal();
     signal_manager->close();
 
     updateCaption();
@@ -1047,26 +1042,19 @@ void TopWidget::selectZoom(int index)
     if (!m_main_widget) return;
     if (!m_zoomselect) return;
     if (index < 0) return;
-    if (index >= m_zoom_factors.count()) return;
+    if (index >= m_zoomselect->count()) return;
 
-    if (m_zoomselect->count() > m_zoom_factors.count()) {
-	// selected the special entry at top
-	if (index == 0) return;
-
-	// remove user-defined entry
-	m_zoomselect->blockSignals(true);
-	while (m_zoomselect->count() > m_zoom_factors.count())
-	    m_zoomselect->removeItem(0);
-	m_zoomselect->blockSignals(false);
-	index--;
-    }
+    QVariant v = m_zoomselect->itemData(index, ZOOM_DATA_TIME);
+    unsigned int ms = 1;
+    bool ok = false;
+    if (v.isValid()) ms = v.toUInt(&ok);
+    if (!ok) ms = 1;
 
     const double rate = signal_manager->rate();
-    const double ms = m_zoom_factors[index].second;
     unsigned int width = m_main_widget->displayWidth();
     Q_ASSERT(width > 1);
     if (width <= 1) width = 2;
-    const double new_zoom = rint(((rate * ms) / 1E3) -1 ) /
+    const double new_zoom = rint(((rate * ms) / 1.0E3) -1 ) /
 	static_cast<double>(width - 1);
     m_main_widget->setZoom(new_zoom);
 
@@ -1086,18 +1074,20 @@ void TopWidget::setZoomInfo(double zoom)
     if (zoom <= 0.0) return; // makes no sense or signal is empty
     if (!m_zoomselect) return;
 
+    double rate = (signal_manager) ? signal_manager->rate() : 0.0;
+    double ms   = (rate > 0) ?
+	(((m_main_widget->displaySamples()) * 1E3) / rate) : 0;
+
     QString strZoom;
     if ((signal_manager) && (signal_manager->tracks())) {
-	double rate = signal_manager->rate();
 	if (rate > 0) {
 	    // time display mode
-	    double ms = m_main_widget->displaySamples() * 1E3 / rate;
-	    int s = static_cast<int>(floor(ms / 1000.0));
-	    int m = static_cast<int>(floor(s / 60.0));
+	    int s = static_cast<int>(ms) / 1000;
+	    int m = s / 60;
 
-	    if (m >= 1) {
+	    if (ms >= 60*1000) {
 		strZoom = strZoom.sprintf("%02d:%02d min", m, s % 60);
-	    } else if (s >= 1) {
+	    } else if (ms >= 1000) {
 		strZoom = strZoom.sprintf("%d sec", s);
 	    } else if (ms >= 1) {
 		strZoom = strZoom.sprintf("%d ms",
@@ -1112,28 +1102,60 @@ void TopWidget::setZoomInfo(double zoom)
 	}
     }
 
+    m_zoomselect->blockSignals(true);
+
+    // if the text is equal to an entry in the current list -> keep it
     if (m_zoomselect->contains(strZoom)) {
-	// select existing entry
-	m_zoomselect->blockSignals(true);
-	while (m_zoomselect->count() > m_zoom_factors.count())
-	    m_zoomselect->removeItem(0);
+	// select existing entry, string match
 	m_zoomselect->setCurrentIndex(m_zoomselect->findText(strZoom));
-	m_zoomselect->blockSignals(false);
     } else {
-	// add a new entry at the top
-	m_zoomselect->blockSignals(true);
-	while (m_zoomselect->count() > m_zoom_factors.count())
-	    m_zoomselect->removeItem(0);
-	m_zoomselect->insertItem(-1, strZoom);
-	m_zoomselect->setCurrentIndex(0);
-	m_zoomselect->blockSignals(false);
+	// remove user defined entries and scan for more or less exact match
+	int i = 0;
+	int match = -1;
+	while (i < m_zoomselect->count()) {
+	    QVariant v = m_zoomselect->itemData(i, ZOOM_DATA_PREDEFINED);
+	    if (!v.isValid() || !v.toBool()) {
+		m_zoomselect->removeItem(i);
+	    } else {
+		QVariant v = m_zoomselect->itemData(i, ZOOM_DATA_TIME);
+		bool ok = false;
+		double t = v.toDouble(&ok);
+		if (ok && (t > 0) && fabs(1 - (t / ms)) < (1.0 / 60.0)) {
+		    match = i;
+		}
+		i++;
+	    }
+	}
+
+	if (match >= 0) {
+	    // use an exact match from the list
+	    i = match;
+	} else if (rate > 0) {
+	    // time mode:
+	    // find the best index where to insert the new user defined value
+	    for (i = 0; i < m_zoomselect->count(); i++) {
+		QVariant v = m_zoomselect->itemData(i, ZOOM_DATA_TIME);
+		bool ok = false;
+		double t = v.toDouble(&ok);
+		if (!ok) continue;
+		if (t > ms) break;
+	    }
+	    m_zoomselect->insertItem(i, strZoom);
+	    m_zoomselect->setItemData(i, QVariant(ms), ZOOM_DATA_TIME);
+	} else {
+	    // percent mode -> just insert at top
+	    m_zoomselect->insertItem(-1, strZoom);
+	    i = 0;
+	}
+	m_zoomselect->setCurrentIndex(i);
     }
+
+    m_zoomselect->blockSignals(false);
 }
 
 //***************************************************************************
 void TopWidget::metaDataChanged(Kwave::MetaDataList meta_data)
 {
-
     Q_ASSERT(statusBar());
     Q_ASSERT(m_menu_manager);
     if (!statusBar() || !m_menu_manager) return;
@@ -1276,6 +1298,9 @@ void TopWidget::updatePlaybackPos(sample_index_t offset)
 	            Kwave::dottedNumber(offset));
     }
     statusBar()->showMessage(txt, 2000);
+
+    // make sure that the current playback position is visible
+    m_main_widget->scrollTo(offset);
 }
 
 //***************************************************************************
@@ -1392,6 +1417,46 @@ void TopWidget::updateMenu()
     clipboardChanged(have_clipboard_data);
 }
 
+//***************************************************************************
+void TopWidget::resetToolbarToDefaults()
+{
+    KToolBar *toolbar_file        = toolBar(TOOLBAR_FILE);
+    KToolBar *toolbar_edit        = toolBar(TOOLBAR_EDIT);
+    KToolBar *toolbar_record_play = toolBar(TOOLBAR_RECORD_PLAY);
+    KToolBar *toolbar_zoom        = toolBar(TOOLBAR_ZOOM);
+
+    int icon_size_def = style()->pixelMetric(QStyle::PM_ToolBarIconSize);
+    int icon_size_big = style()->pixelMetric(QStyle::PM_LargeIconSize);
+
+    // change style to "symbols only mode" and set standard size
+    foreach(KToolBar *bar, toolBars()) {
+	bar->setToolButtonStyle(Qt::ToolButtonIconOnly);
+	bar->setIconSize( QSize(icon_size_def, icon_size_def) );
+    }
+
+    // re-order the tool bars:
+    // ---------------------------
+    // file  |  edit  |  zoom  |
+    // ---------------------------
+    // record/play  |
+    // ---------------------------
+    insertToolBar(toolbar_record_play, toolbar_zoom);
+    insertToolBar(toolbar_zoom,        toolbar_edit);
+    insertToolBar(toolbar_edit,        toolbar_file);
+
+    // move record/playback into a seperate line, below file/edit
+    insertToolBarBreak(toolbar_record_play);
+
+    // let record/playback and zoom use bigger icons
+    toolbar_record_play->setIconSize(QSize(icon_size_big, icon_size_big));
+    toolbar_zoom->setIconSize(QSize(icon_size_big, icon_size_big));
+
+    foreach(KToolBar *bar, toolBars()) {
+	bar->update();
+	bar->show();
+    }
+}
+
 //***************************************************************************
 void TopWidget::updateToolbar()
 {
@@ -1413,99 +1478,6 @@ void TopWidget::updateToolbar()
         m_action_zoomall->setEnabled(have_signal);
     if (m_action_zoomselect)
         m_action_zoomselect->setEnabled(have_signal);
-
-    updatePlaybackControls();
-}
-
-//***************************************************************************
-void TopWidget::updatePlaybackControls()
-{
-    SignalManager *signal_manager = m_context.signalManager();
-    Q_ASSERT(signal_manager);
-    if (!signal_manager) return;
-
-    bool have_signal = signal_manager->tracks();
-    bool playing = signal_manager->playbackController().running();
-    bool paused  = signal_manager->playbackController().paused();
-
-    // stop blinking
-    if (m_pause_timer) {
-	m_pause_timer->stop();
-	delete m_pause_timer;
-	m_pause_timer = 0;
-	if (m_action_pause)
-	    m_action_pause->setIcon(QIcon(QPixmap(xpm_pause)));
-    }
-
-    // enable/disable the buttons
-
-    if (m_action_play)
-	m_action_play->setEnabled(have_signal && !playing);
-    if (m_action_loop)
-	m_action_loop->setEnabled(have_signal && !playing);
-    if (m_action_pause)
-	m_action_pause->setEnabled(have_signal && (playing || paused));
-    if (m_action_stop)
-	m_action_stop->setEnabled(have_signal && (playing || paused));
-
-    m_menu_manager->setItemEnabled("ID_PLAYBACK_START",
-	have_signal && !playing);
-    m_menu_manager->setItemEnabled("ID_PLAYBACK_LOOP",
-	have_signal && !playing);
-    m_menu_manager->setItemEnabled("ID_PLAYBACK_PAUSE",
-	have_signal && (playing));
-    m_menu_manager->setItemEnabled("ID_PLAYBACK_CONTINUE",
-	have_signal && (paused));
-    m_menu_manager->setItemEnabled("ID_PLAYBACK_STOP",
-	have_signal && (playing || paused));
-
-}
-
-//***************************************************************************
-void TopWidget::playbackPaused()
-{
-    updateToolbar();
-
-    if (!m_pause_timer) {
-	m_pause_timer = new QTimer(this);
-	Q_ASSERT(m_pause_timer);
-	if (!m_pause_timer) return;
-
-	m_pause_timer->start(500);
-	connect(m_pause_timer, SIGNAL(timeout()),
-	        this, SLOT(blinkPause()));
-	if (m_action_pause) m_action_pause->setIcon(QIcon(xpm_pause2));
-	m_blink_on = true;
-    }
-}
-
-//***************************************************************************
-void TopWidget::blinkPause()
-{
-    Q_ASSERT(m_action_pause);
-    if (!m_action_pause) return;
-    m_action_pause->setIcon(QIcon(m_blink_on ?
-	QPixmap(xpm_pause2) : QPixmap(xpm_pause)));
-    m_blink_on = !m_blink_on;
-}
-
-//***************************************************************************
-void TopWidget::pausePressed()
-{
-    SignalManager *signal_manager = m_context.signalManager();
-    Q_ASSERT(signal_manager);
-    if (!signal_manager) return;
-
-    bool have_signal = signal_manager->tracks();
-    bool playing     = signal_manager->playbackController().running();
-
-    if (!have_signal) return;
-
-    if (playing) {
-	signal_manager->playbackController().playbackPause();
-    } else {
-	signal_manager->playbackController().playbackContinue();
-    }
 }
 
 //***************************************************************************
