@@ -39,13 +39,13 @@
 #include "Filter.h"
 
 //***************************************************************************
-Signal::Signal()
+Kwave::Signal::Signal()
     :m_tracks(), m_lock_tracks()
 {
 }
 
 //***************************************************************************
-Signal::Signal(unsigned int tracks, sample_index_t length)
+Kwave::Signal::Signal(unsigned int tracks, sample_index_t length)
     :m_tracks(), m_lock_tracks()
 {
     while (tracks--) {
@@ -54,13 +54,13 @@ Signal::Signal(unsigned int tracks, sample_index_t length)
 }
 
 //***************************************************************************
-Signal::~Signal()
+Kwave::Signal::~Signal()
 {
     close();
 }
 
 //***************************************************************************
-void Signal::close()
+void Kwave::Signal::close()
 {
     QWriteLocker lock(&m_lock_tracks);
 
@@ -70,36 +70,40 @@ void Signal::close()
 }
 
 //***************************************************************************
-Track *Signal::insertTrack(unsigned int index, sample_index_t length)
+Kwave::Track *Kwave::Signal::insertTrack(unsigned int index,
+                                         sample_index_t length)
 {
-    Track *t = 0;
+    Kwave::Track *t = 0;
     {
 	QWriteLocker lock(&m_lock_tracks);
 
-	t = new Track(length);
+	t = new Kwave::Track(length);
 	Q_ASSERT(t);
 	if (!t) return 0;
 
 	// clip the track index
 	if (static_cast<int>(index) > m_tracks.count())
 	    index = m_tracks.count();
-	    
+
 	// insert / append to the list
 	m_tracks.insert(index, t);
 
 	// connect to the new track's signals
-	connect(t, SIGNAL(sigSamplesDeleted(Track *, sample_index_t,
+	connect(t, SIGNAL(sigSamplesDeleted(Kwave::Track *, sample_index_t,
 	    sample_index_t)),
-	    this, SLOT(slotSamplesDeleted(Track *, sample_index_t,
+	    this, SLOT(slotSamplesDeleted(Kwave::Track *, sample_index_t,
 	    sample_index_t)));
-	connect(t, SIGNAL(sigSamplesInserted(Track *, sample_index_t,
+	connect(t, SIGNAL(sigSamplesInserted(Kwave::Track *, sample_index_t,
 	    sample_index_t)),
-	    this, SLOT(slotSamplesInserted(Track *, sample_index_t,
+	    this, SLOT(slotSamplesInserted(Kwave::Track *, sample_index_t,
 	    sample_index_t)));
-	connect(t, SIGNAL(sigSamplesModified(Track *, sample_index_t,
+	connect(t, SIGNAL(sigSamplesModified(Kwave::Track *, sample_index_t,
 	    sample_index_t)),
-	    this, SLOT(slotSamplesModified(Track *, sample_index_t,
+	    this, SLOT(slotSamplesModified(Kwave::Track *, sample_index_t,
 	    sample_index_t)));
+
+	connect(t, SIGNAL(sigSelectionChanged(bool)),
+	    this, SIGNAL(sigTrackSelectionChanged(bool)));
     }
 
     // track has been inserted
@@ -109,16 +113,16 @@ Track *Signal::insertTrack(unsigned int index, sample_index_t length)
 
 
 //***************************************************************************
-Track *Signal::appendTrack(sample_index_t length)
+Kwave::Track *Kwave::Signal::appendTrack(sample_index_t length)
 {
     return insertTrack(tracks(), length);
 }
 
 //***************************************************************************
-void Signal::deleteTrack(unsigned int index)
+void Kwave::Signal::deleteTrack(unsigned int index)
 {
     // remove the track from the list but do not delete it
-    Track *t = 0;
+    Kwave::Track *t = 0;
     {
 	QWriteLocker lock(&m_lock_tracks);
 	if (static_cast<int>(index) > m_tracks.count())
@@ -139,7 +143,7 @@ void Signal::deleteTrack(unsigned int index)
 }
 
 //***************************************************************************
-Kwave::Writer *Signal::openWriter(unsigned int track,
+Kwave::Writer *Kwave::Signal::openWriter(unsigned int track,
 	InsertMode mode, sample_index_t left, sample_index_t right)
 {
     QReadLocker lock(&m_lock_tracks);
@@ -149,13 +153,13 @@ Kwave::Writer *Signal::openWriter(unsigned int track,
 	return 0; // track does not exist !
     }
 
-    Track *t = m_tracks.at(track);
+    Kwave::Track *t = m_tracks.at(track);
     Q_ASSERT(t);
     return (t) ? t->openWriter(mode, left, right) : 0;
 }
 
 //***************************************************************************
-SampleReader *Signal::openSampleReader(Kwave::ReaderMode mode,
+SampleReader *Kwave::Signal::openSampleReader(Kwave::ReaderMode mode,
 	unsigned int track, sample_index_t left, sample_index_t right)
 {
     QReadLocker lock(&m_lock_tracks);
@@ -163,13 +167,13 @@ SampleReader *Signal::openSampleReader(Kwave::ReaderMode mode,
     if (static_cast<int>(track) >= m_tracks.count())
 	return 0; // track does not exist !
 
-    Track *t = m_tracks.at(track);
+    Kwave::Track *t = m_tracks.at(track);
     Q_ASSERT(t);
     return (t) ? t->openSampleReader(mode, left, right) : 0;
 }
 
 //***************************************************************************
-QList<unsigned int> Signal::allTracks()
+QList<unsigned int> Kwave::Signal::allTracks()
 {
     unsigned int track;
     unsigned int tracks = this->tracks();
@@ -183,8 +187,8 @@ QList<unsigned int> Signal::allTracks()
 }
 
 //***************************************************************************
-void Signal::deleteRange(unsigned int track, sample_index_t offset,
-                         sample_index_t length)
+void Kwave::Signal::deleteRange(unsigned int track, sample_index_t offset,
+                                sample_index_t length)
 {
     QReadLocker lock(&m_lock_tracks);
 
@@ -192,14 +196,14 @@ void Signal::deleteRange(unsigned int track, sample_index_t offset,
     if (static_cast<int>(track) >= m_tracks.count())
 	return; // track does not exist !
 
-    Track *t = m_tracks.at(track);
+    Kwave::Track *t = m_tracks.at(track);
     Q_ASSERT(t);
     if (t) t->deleteRange(offset, length);
 }
 
 //***************************************************************************
-void Signal::insertSpace(unsigned int track, sample_index_t offset,
-                         sample_index_t length)
+void Kwave::Signal::insertSpace(unsigned int track, sample_index_t offset,
+                                sample_index_t length)
 {
     QReadLocker lock(&m_lock_tracks);
 
@@ -207,25 +211,25 @@ void Signal::insertSpace(unsigned int track, sample_index_t offset,
     if (static_cast<int>(track) >= m_tracks.count())
 	return; // track does not exist !
 
-    Track *t = m_tracks.at(track);
+    Kwave::Track *t = m_tracks.at(track);
     Q_ASSERT(t);
     if (t) t->insertSpace(offset, length);
 }
 
 //***************************************************************************
-unsigned int Signal::tracks()
+unsigned int Kwave::Signal::tracks()
 {
     QReadLocker lock(&m_lock_tracks);
     return m_tracks.count();
 }
 
 //***************************************************************************
-sample_index_t Signal::length()
+sample_index_t Kwave::Signal::length()
 {
     QReadLocker lock(&m_lock_tracks);
 
     sample_index_t max = 0;
-    foreach (Track *track, m_tracks) {
+    foreach (Kwave::Track *track, m_tracks) {
 	if (!track) continue;
 	sample_index_t len = track->length();
 	if (len > max) max = len;
@@ -234,7 +238,7 @@ sample_index_t Signal::length()
 }
 
 //***************************************************************************
-bool Signal::trackSelected(unsigned int track)
+bool Kwave::Signal::trackSelected(unsigned int track)
 {
     QReadLocker lock(&m_lock_tracks);
 
@@ -245,7 +249,7 @@ bool Signal::trackSelected(unsigned int track)
 }
 
 //***************************************************************************
-void Signal::selectTrack(unsigned int track, bool select)
+void Kwave::Signal::selectTrack(unsigned int track, bool select)
 {
     QReadLocker lock(&m_lock_tracks);
 
@@ -415,7 +419,7 @@ void Signal::selectTrack(unsigned int track, bool select)
 ////    }
 //}
 ////*********************************************************
-//void Signal::movingFilter (Filter *filter, int tap, Curve *points, int low, int high)
+//void Kwave::Signal::movingFilter (Filter *filter, int tap, Curve *points, int low, int high)
 //{
 //    Interpolation interpolation (0);
 //
@@ -487,7 +491,7 @@ void Signal::selectTrack(unsigned int track, bool select)
 //}
 //
 ////*********************************************************
-//void Signal::replaceStutter (int len1, int len2) {
+//void Kwave::Signal::replaceStutter (int len1, int len2) {
 //    int *sample = &(this->sample[lmarker]);
 //
 //    int j;
@@ -501,7 +505,7 @@ void Signal::selectTrack(unsigned int track, bool select)
 //}
 //
 ////**********************************************************
-//void Signal::mixPaste (Signal *signal) {
+//void Kwave::Signal::mixPaste (Signal *signal) {
 //    int pastelength = signal->getLength ();
 //    int *paste = signal->getSample();
 //    int marked = (lmarker != rmarker) ? rmarker - lmarker + 1 : length;
@@ -516,33 +520,36 @@ void Signal::selectTrack(unsigned int track, bool select)
 //    }
 
 //***************************************************************************
-unsigned int Signal::trackIndex(const Track *track)
+unsigned int Kwave::Signal::trackIndex(const Kwave::Track *track)
 {
     QReadLocker lock(&m_lock_tracks);
 
-    int index = m_tracks.indexOf(const_cast<Track *>(track));
+    int index = m_tracks.indexOf(const_cast<Kwave::Track *>(track));
     return (index >= 0) ? index : m_tracks.count();
 }
 
 //***************************************************************************
-void Signal::slotSamplesInserted(Track *src, sample_index_t offset,
-                                 sample_index_t length)
+void Kwave::Signal::slotSamplesInserted(Kwave::Track *src,
+                                        sample_index_t offset,
+                                        sample_index_t length)
 {
     unsigned int track = trackIndex(src);
     emit sigSamplesInserted(track, offset, length);
 }
 
 //***************************************************************************
-void Signal::slotSamplesDeleted(Track *src, sample_index_t offset,
-                                sample_index_t length)
+void Kwave::Signal::slotSamplesDeleted(Kwave::Track *src,
+                                       sample_index_t offset,
+                                       sample_index_t length)
 {
     unsigned int track = trackIndex(src);
     emit sigSamplesDeleted(track, offset, length);
 }
 
 //***************************************************************************
-void Signal::slotSamplesModified(Track *src, sample_index_t offset,
-                                 sample_index_t length)
+void Kwave::Signal::slotSamplesModified(Kwave::Track *src,
+                                        sample_index_t offset,
+                                        sample_index_t length)
 {
     unsigned int track = trackIndex(src);
     emit sigSamplesModified(track, offset, length);
