@@ -46,11 +46,11 @@ class KUrl;
 class MultiTrackReader;
 class SampleReader;
 class SignalWidget;
-class Track;
 class UndoAction;
 class UndoTransaction;
 class UndoTransactionGuard;
 namespace Kwave { class MultiTrackWriter; }
+namespace Kwave { class Track; }
 namespace Kwave { class Writer; }
 
 #define NEW_FILENAME i18n("New File")
@@ -369,7 +369,7 @@ signals:
      * @param index position of the new track [0...tracks()-1]
      * @param track reference to the new track
      */
-    void sigTrackInserted(unsigned int index, Track *track);
+    void sigTrackInserted(unsigned int index, Kwave::Track *track);
 
     /**
      * Signals that a track has been deleted.
@@ -377,6 +377,12 @@ signals:
      */
     void sigTrackDeleted(unsigned int index);
 
+    /**
+     * Signals that the selection of one of the tracks has changed
+     * @param enabled state of the track, true=selected
+     */
+    void sigTrackSelectionChanged(bool enabled);
+
     /**
      * Emitted if samples have been inserted into a track. This implies
      * a modification of the inserted data, so no extra sigSamplesModified
@@ -448,7 +454,7 @@ private slots:
      * @see Signal::sigTrackInserted
      * @internal
      */
-    void slotTrackInserted(unsigned int index, Track *track);
+    void slotTrackInserted(unsigned int index, Kwave::Track *track);
 
     /**
      * Connected to the signal's sigTrackInserted.
@@ -537,7 +543,7 @@ protected:
      * data if successful.
      * @param action UndoAction to that is to be registered
      * @return true if the action is allowed, false if the user has
-     *         choosen to abort the operation if the memory limit of
+     *         chosen to abort the operation if the memory limit of
      *         the undo buffer would be exceeded. The return value
      *         will also be false if the action is null.
      * @note If undo is currently not enabled, the passed UndoAction
@@ -652,7 +658,7 @@ private:
     bool m_modified_enabled;
 
     /** signal with multiple tracks */
-    Signal m_signal;
+    Kwave::Signal m_signal;
 
     /** the current selection */
     Selection m_selection;
