@@ -25,6 +25,14 @@
 // define this for using only slow Qt array functions
 #undef STRICTLY_QT
 
+#ifndef unlikely
+#define unlikely(x) (__builtin_expect((x),0))
+#endif
+
+#ifndef likely
+#define likely(x) (__builtin_expect((x),1))
+#endif
+
 //***************************************************************************
 //***************************************************************************
 Stripe::MappedArray::MappedArray(Stripe &stripe)
@@ -209,14 +217,14 @@ Stripe::Stripe(const Stripe &other)
 }
 
 //***************************************************************************
-Stripe::Stripe(unsigned int start)
+Stripe::Stripe(sample_index_t start)
     :m_lock(), m_data(new StripeStorage)
 {
     if (m_data) m_data->m_start = start;
 }
 
 //***************************************************************************
-Stripe::Stripe(unsigned int start, const Kwave::SampleArray &samples)
+Stripe::Stripe(sample_index_t start, const Kwave::SampleArray &samples)
     :m_lock(), m_data(new StripeStorage)
 {
     if (m_data) m_data->m_start = start;
@@ -224,7 +232,7 @@ Stripe::Stripe(unsigned int start, const Kwave::SampleArray &samples)
 }
 
 //***************************************************************************
-Stripe::Stripe(unsigned int start, Stripe &stripe, unsigned int offset)
+Stripe::Stripe(sample_index_t start, Stripe &stripe, unsigned int offset)
     :m_lock(), m_data(new StripeStorage)
 {
     if (!m_data) return;
@@ -252,13 +260,13 @@ Stripe::~Stripe()
 }
 
 //***************************************************************************
-unsigned int Stripe::start() const
+sample_index_t Stripe::start() const
 {
     return (m_data) ? m_data->m_start : 0;
 }
 
 //***************************************************************************
-void Stripe::setStart(unsigned int start)
+void Stripe::setStart(sample_index_t start)
 {
     QMutexLocker lock(&m_lock);
     m_data.detach();
@@ -272,7 +280,7 @@ unsigned int Stripe::length() const
 }
 
 //***************************************************************************
-unsigned int Stripe::end() const
+sample_index_t Stripe::end() const
 {
     return (m_data) ? (m_data->m_start +
 	((m_data->m_length) ? (m_data->m_length - 1) : 0)) : 0;
@@ -526,10 +534,22 @@ void Stripe::minMax(unsigned int first, unsigned int last,
     Q_ASSERT(first <= last);
     Q_ASSERT(last < m_data->m_length);
     buffer += first;
-    while (first++ <= last) {
+    unsigned int remaining = last - first + 1;
+
+    // speedup: process a block of 8 samples at once, to allow loop unrolling
+    const unsigned int block = 8;
+    while (likely(remaining >= block)) {
+	for (unsigned int count = 0; count < block; count++) {
+	    register sample_t s = *(buffer++);
+	    if (unlikely(s < lo)) lo = s;
+	    if (unlikely(s > hi)) hi = s;
+	}
+	remaining -= block;
+    }
+    while (likely(remaining--)) {
 	register sample_t s = *(buffer++);
-	if (s < lo) lo = s;
-	if (s > hi) hi = s;
+	if (unlikely(s < lo)) lo = s;
+	if (unlikely(s > hi)) hi = s;
     }
     min = lo;
     max = hi;
