@@ -52,18 +52,18 @@
 #define STRIPE_LENGTH_MINIMUM (STRIPE_LENGTH_OPTIMAL / 2)
 
 //***************************************************************************
-Track::Track()
+Kwave::Track::Track()
     :m_lock(), m_lock_usage(), m_stripes(), m_selected(true)
 {
 }
 
 //***************************************************************************
-Track::Track(unsigned int length)
+Kwave::Track::Track(sample_index_t length)
     :m_lock(), m_lock_usage(), m_stripes(), m_selected(true)
 {
-    if (length < 2*STRIPE_LENGTH_OPTIMAL)
-	appendStripe(length);
-    else {
+    if (length < 2*STRIPE_LENGTH_OPTIMAL) {
+	if (length) appendStripe(length);
+    } else {
 	Stripe s(length - STRIPE_LENGTH_OPTIMAL);
 	s.resize(STRIPE_LENGTH_OPTIMAL);
 	if (s.length()) m_stripes.append(s);
@@ -71,7 +71,7 @@ Track::Track(unsigned int length)
 }
 
 //***************************************************************************
-Track::~Track()
+Kwave::Track::~Track()
 {
     // wait until all readers are finished
     QWriteLocker lock_usage(&m_lock_usage);
@@ -84,11 +84,11 @@ Track::~Track()
 }
 
 //***************************************************************************
-void Track::appendStripe(unsigned int length)
+void Kwave::Track::appendStripe(sample_index_t length)
 {
 //     SharedLockGuard lock(m_lock, true);
-    unsigned int start = unlockedLength();
-    unsigned int len;
+    sample_index_t start = unlockedLength();
+    sample_index_t len;
 
     do {
 	len = length;
@@ -107,7 +107,7 @@ void Track::appendStripe(unsigned int length)
 }
 
 //***************************************************************************
-Stripe Track::splitStripe(Stripe &stripe, unsigned int offset)
+Stripe Kwave::Track::splitStripe(Stripe &stripe, unsigned int offset)
 {
     Q_ASSERT(offset < stripe.length());
     Q_ASSERT(offset);
@@ -121,21 +121,21 @@ Stripe Track::splitStripe(Stripe &stripe, unsigned int offset)
     // shrink the old stripe
     stripe.resize(offset);
 
-//     qDebug("Track::splitStripe(%p, %u): new stripe at [%u ... %u] (%u)",
+//     qDebug("Kwave::Track::splitStripe(%p, %u): new stripe at [%u ... %u] (%u)",
 //            stripe, offset, s->start(), s->end(), s->length());
 
     return s;
 }
 
 //***************************************************************************
-unsigned int Track::length()
+sample_index_t Kwave::Track::length()
 {
     QReadLocker lock(&m_lock);
     return unlockedLength();
 }
 
 //***************************************************************************
-unsigned int Track::unlockedLength()
+sample_index_t Kwave::Track::unlockedLength()
 {
     if (m_stripes.isEmpty()) return 0;
     const Stripe &s = m_stripes.last();
@@ -143,8 +143,8 @@ unsigned int Track::unlockedLength()
 }
 
 //***************************************************************************
-Kwave::Writer *Track::openWriter(InsertMode mode,
-	unsigned int left, unsigned int right)
+Kwave::Writer *Kwave::Track::openWriter(InsertMode mode,
+	sample_index_t left, sample_index_t right)
 {
     // create the input stream
     Kwave::Writer *stream = new Kwave::TrackWriter(*this, mode, left, right);
@@ -154,20 +154,20 @@ Kwave::Writer *Track::openWriter(InsertMode mode,
 }
 
 //***************************************************************************
-SampleReader *Track::openSampleReader(Kwave::ReaderMode mode,
-	unsigned int left, unsigned int right)
+SampleReader *Kwave::Track::openSampleReader(Kwave::ReaderMode mode,
+	sample_index_t left, sample_index_t right)
 {
     QReadLocker lock(&m_lock);
 
-    unsigned int length = unlockedLength();
+    sample_index_t length = unlockedLength();
     if (right >= length) right = (length) ? (length - 1) : 0;
 
     // collect all stripes that are in the requested range
     QList<Stripe> stripes;
     foreach (const Stripe &stripe, m_stripes) {
 	if (!stripe.length()) continue;
-	unsigned int start = stripe.start();
-	unsigned int end   = stripe.end();
+	sample_index_t start = stripe.start();
+	sample_index_t end   = stripe.end();
 
 	if (end < left) continue; // not yet in range
 	if (start > right) break; // done
@@ -182,12 +182,12 @@ SampleReader *Track::openSampleReader(Kwave::ReaderMode mode,
 }
 
 //***************************************************************************
-void Track::deleteRange(unsigned int offset, unsigned int length,
-                        bool make_gap)
+void Kwave::Track::deleteRange(sample_index_t offset, sample_index_t length,
+                               bool make_gap)
 {
     if (!length) return;
 
-//     qDebug("Track::deleteRange() [%u ... %u] (%u)",
+//     qDebug("Kwave::Track::deleteRange() [%u ... %u] (%u)",
 // 	offset, offset + length - 1, length);
 
     {
@@ -199,27 +199,27 @@ void Track::deleteRange(unsigned int offset, unsigned int length,
 }
 
 //***************************************************************************
-bool Track::insertSpace(unsigned int offset, unsigned int shift)
+bool Kwave::Track::insertSpace(sample_index_t offset, sample_index_t shift)
 {
-//     qDebug("Track::insertSpace(offset=%u,shift=%u)",offset, shift);
+//     qDebug("Kwave::Track::insertSpace(offset=%u,shift=%u)",offset, shift);
     if (!shift) return true;
 
     {
 	QWriteLocker lock(&m_lock);
-	unsigned int len = unlockedLength();
+	sample_index_t len = unlockedLength();
 	if (offset < len) {
 	    // find out whether the offset is within a stripe and
 	    // split that one if necessary
 	    QMutableListIterator<Stripe> it(m_stripes);
 	    while (it.hasNext()) {
 		Stripe &s = it.next();
-		unsigned int end    = s.end();
+		sample_index_t end    = s.end();
 		if (end < offset) continue; // skip, stripe is at left
 
-		unsigned int start  = s.start();
+		sample_index_t start  = s.start();
 		if (start >= offset) break; // not "within" the stripe
 
-// 		qDebug("Track::insertSpace => splitting [%u...%u]",start,end);
+// 		qDebug("Kwave::Track::insertSpace => splitting [%u...%u]",start,end);
 		Stripe new_stripe = splitStripe(s, offset - start);
 		if (!new_stripe.length()) return false; // OOM ?
 		it.insert(new_stripe);
@@ -227,10 +227,10 @@ bool Track::insertSpace(unsigned int offset, unsigned int shift)
 	    }
 
 	    // move all stripes that are after the offset right
-// 	    qDebug("Track::insertSpace => moving right");
+// 	    qDebug("Kwave::Track::insertSpace => moving right");
 	    moveRight(offset, shift);
 	} else {
-// 	    qDebug("Track::insertSpace => appending stripe at %u", offset + shift - 1);
+// 	    qDebug("Kwave::Track::insertSpace => appending stripe at %u", offset + shift - 1);
 	    Stripe s(offset + shift - 1);
 	    s.resize(1);
 	    if (s.length()) m_stripes.append(s);
@@ -243,21 +243,21 @@ bool Track::insertSpace(unsigned int offset, unsigned int shift)
 }
 
 //***************************************************************************
-void Track::unlockedDelete(unsigned int offset, unsigned int length,
-                           bool make_gap)
+void Kwave::Track::unlockedDelete(sample_index_t offset, sample_index_t length,
+                                  bool make_gap)
 {
     if (!length) return;
 
     // add all stripes within the specified range to the list
-    unsigned int left  = offset;
-    unsigned int right = offset + length - 1;
+    sample_index_t left  = offset;
+    sample_index_t right = offset + length - 1;
 
     QMutableListIterator<Stripe> it(m_stripes);
     it.toBack();
     while (it.hasPrevious()) {
 	Stripe &s = it.previous();
-	unsigned int start  = s.start();
-	unsigned int end    = s.end();
+	sample_index_t start  = s.start();
+	sample_index_t end    = s.end();
 
 	if (end   < left)  break;    // done, stripe is at left
 	if (start > right) continue; // skip, stripe is at right
@@ -343,17 +343,23 @@ void Track::unlockedDelete(unsigned int offset, unsigned int length,
 }
 
 //***************************************************************************
-void Track::select(bool selected)
+void Kwave::Track::select(bool selected)
 {
     if (m_selected == selected) return;
     m_selected = selected;
-    emit sigSelectionChanged();
+    emit sigSelectionChanged(m_selected);
 }
 
 //***************************************************************************
-bool Track::appendAfter(Stripe *stripe,  unsigned int offset,
-                        const Kwave::SampleArray &buffer,
-                        unsigned int buf_offset, unsigned int length)
+void Kwave::Track::toggleSelection()
+{
+    select(!selected());
+}
+
+//***************************************************************************
+bool Kwave::Track::appendAfter(Stripe *stripe,  sample_index_t offset,
+                               const Kwave::SampleArray &buffer,
+                               unsigned int buf_offset, unsigned int length)
 {
     Q_ASSERT(buf_offset + length <= buffer.size());
     if (buf_offset + length > buffer.size()) return false;
@@ -367,7 +373,7 @@ bool Track::appendAfter(Stripe *stripe,  unsigned int offset,
 	if (len + stripe->length() > STRIPE_LENGTH_MAXIMUM)
 	    len = STRIPE_LENGTH_MAXIMUM - stripe->length();
 
-// 	qDebug("Track::appendAfter(): appending %u samples to %p",
+// 	qDebug("Kwave::Track::appendAfter(): appending %u samples to %p",
 // 	       len, stripe);
 	if (!stripe->append(buffer, buf_offset, len))
 	    return false; // out of memory
@@ -381,17 +387,17 @@ bool Track::appendAfter(Stripe *stripe,  unsigned int offset,
 
     // append new stripes as long as there is something remaining
     while (length) {
-	unsigned int len = length;
+	sample_index_t len = length;
 	if (len > STRIPE_LENGTH_MAXIMUM)
 	    len = STRIPE_LENGTH_MAXIMUM;
 
-// 	qDebug("Track::appendAfter: new stripe, ofs=%u, len=%u",
+// 	qDebug("Kwave::Track::appendAfter: new stripe, ofs=%u, len=%u",
 // 	       offset, len);
 	Stripe new_stripe(offset);
 
 	// append to the new stripe
 	if (!new_stripe.append(buffer, buf_offset, len)) {
-	    qWarning("Track::appendAfter FAILED / OOM");
+	    qWarning("Kwave::Track::appendAfter FAILED / OOM");
 	    return false; /* out of memory */
 	}
 	Q_ASSERT(new_stripe.length() == len);
@@ -402,12 +408,12 @@ bool Track::appendAfter(Stripe *stripe,  unsigned int offset,
 	if (index_before >= 0) {
 	    // insert after the last one
 	    index_before++;
-// 	    qDebug("Track::appendAfter: insert after %p [%10u - %10u]",
+// 	    qDebug("Kwave::Track::appendAfter: insert after %p [%10u - %10u]",
 // 		stripe, stripe->start(), stripe->end());
 	    m_stripes.insert(index_before, new_stripe);
 	} else {
 	    // the one and only or insert before all others
-// 	    qDebug("Track::appendAfter: prepending");
+// 	    qDebug("Kwave::Track::appendAfter: prepending");
 	    m_stripes.prepend(new_stripe);
 	    index_before = 0;
 	}
@@ -420,14 +426,14 @@ bool Track::appendAfter(Stripe *stripe,  unsigned int offset,
 }
 
 //***************************************************************************
-void Track::moveRight(unsigned int offset, unsigned int shift)
+void Kwave::Track::moveRight(sample_index_t offset, sample_index_t shift)
 {
     if (m_stripes.isEmpty()) return;
     QMutableListIterator<Stripe> it(m_stripes);
     it.toBack();
     while (it.hasPrevious()) {
 	Stripe &s = it.previous();
-	unsigned int start = s.start();
+	sample_index_t start = s.start();
 	if (start < offset) break;
 
 	s.setStart(start + shift);
@@ -435,11 +441,11 @@ void Track::moveRight(unsigned int offset, unsigned int shift)
 }
 
 //***************************************************************************
-bool Track::writeSamples(InsertMode mode,
-                         unsigned int offset,
-                         const Kwave::SampleArray &buffer,
-                         unsigned int buf_offset,
-                         unsigned int length)
+bool Kwave::Track::writeSamples(InsertMode mode,
+                                sample_index_t offset,
+                                const Kwave::SampleArray &buffer,
+                                unsigned int buf_offset,
+                                unsigned int length)
 {
     Q_ASSERT(length);
     if (!length) return true; // nothing to do !?
@@ -464,7 +470,7 @@ bool Track::writeSamples(InsertMode mode,
 	case Insert: {
 	    m_lock.lockForWrite();
 
-// 	    qDebug("Track::writeSamples() - Insert @ %u, length=%u",
+// 	    qDebug("Kwave::Track::writeSamples() - Insert @ %u, length=%u",
 // 		   offset, length);
 
 	    // find the stripe into which we insert
@@ -473,8 +479,8 @@ bool Track::writeSamples(InsertMode mode,
 	    QMutableListIterator<Stripe> it(m_stripes);
 	    while (it.hasNext()) {
 		Stripe &s = it.next();
-		unsigned int st  = s.start();
-		unsigned int len = s.length();
+		sample_index_t st  = s.start();
+		sample_index_t len = s.length();
 		if (!len) continue; // skip zero-length tracks
 
 		if (offset >= st + len) stripe_before = &s;
@@ -536,8 +542,8 @@ bool Track::writeSamples(InsertMode mode,
 	    break;
 	}
 	case Overwrite: {
-// 	    const unsigned int left  = offset;
-// 	    const unsigned int right = offset + length - 1;
+// 	    const sample_index_t left  = offset;
+// 	    const sample_index_t right = offset + length - 1;
 // 	    qDebug("writeSamples() - Overwrite [%u - %u]", left, right);
 
 	    {
@@ -571,19 +577,19 @@ bool Track::writeSamples(InsertMode mode,
 }
 
 //***************************************************************************
-void Track::use()
+void Kwave::Track::use()
 {
     m_lock_usage.lockForRead();
 }
 
 //***************************************************************************
-void Track::release()
+void Kwave::Track::release()
 {
     m_lock_usage.unlock();
 }
 
 //***************************************************************************
-void Track::dump()
+void Kwave::Track::dump()
 {
     qDebug("------------------------------------");
     unsigned int index = 0;
@@ -593,14 +599,16 @@ void Track::dump()
 	if (index && (start <= last_end))
 	    qDebug("--- OVERLAP ---");
 	if (start > last_end+1)
-	    qDebug("       : GAP         [%10u - %10u] (%10u)",
-	    last_end + ((index) ? 1 : 0), start - 1,
-	    start - last_end - ((index) ? 1 : 0));
-	qDebug("#%6d: %p - [%10u - %10u] (%10u)",
+	    qDebug("       : GAP         [%10lu - %10lu] (%10lu)",
+	    static_cast<unsigned long int>(last_end + ((index) ? 1 : 0)),
+	    static_cast<unsigned long int>(start - 1),
+	    static_cast<unsigned long int>(start - last_end -
+		((index) ? 1 : 0)));
+	qDebug("#%6d: %p - [%10lu - %10lu] (%10lu)",
 	       index++, static_cast<const void *>(&s),
-	       s.start(),
-	       s.end(),
-	       s.length());
+	       static_cast<unsigned long int>(s.start()),
+	       static_cast<unsigned long int>(s.end()),
+	       static_cast<unsigned long int>(s.length()));
 	last_end = s.end();
     }
     qDebug("------------------------------------");
