@@ -329,7 +329,7 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
     Q_ASSERT(src.tracks() == tracks);
     if (src.tracks() != tracks) return false;
 
-    // check if the choosen compression mode is supported for saving
+    // check if the chosen compression mode is supported for saving
     if ((compression != AF_COMPRESSION_NONE) &&
         (compression != AF_COMPRESSION_G711_ULAW) &&
         (compression != AF_COMPRESSION_G711_ALAW))
@@ -361,7 +361,7 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
     if ((compression == AF_COMPRESSION_G711_ULAW) ||
         (compression == AF_COMPRESSION_G711_ALAW))
     {
-	if ((sample_format != AF_SAMPFMT_TWOSCOMP) &&
+	if ((sample_format != AF_SAMPFMT_TWOSCOMP) ||
 	    (bits          != 16))
 	{
 	    const SampleFormat format(SampleFormat::Signed);
@@ -470,9 +470,8 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
 	for (unsigned int pos = 0; pos < count; pos++) {
 	    for (unsigned int track = 0; track < tracks; track++) {
 		SampleReader *stream = src[track];
-		sample_t sample;
-		Q_ASSERT(!stream->eof());
-		(*stream) >> sample;
+		sample_t sample = 0;
+		if (!stream->eof()) (*stream) >> sample;
 
 		// the following cast is only necessary if
 		// sample_t is not equal to a 32bit int
