@@ -195,7 +195,6 @@ void PlayBackPulseAudio::notifySinkInfo(pa_context *c,
 void PlayBackPulseAudio::notifyStreamState(pa_stream* stream)
 {
     Q_ASSERT(stream);
-    Q_ASSERT(stream = m_pa_stream);
     if (!stream || (stream != m_pa_stream)) return;
 
     switch (pa_stream_get_state(stream)) {
@@ -406,7 +405,7 @@ QString PlayBackPulseAudio::open(const QString &device, double rate,
 
     // make sure that we are connected to the sound server
     if (!connectToServer()) {
-	return i18n("Connection to the PulseAudio server failed.");
+	return i18n("Connecting to the PulseAudio server failed.");
     }
 
     if (!m_device_list.contains(device)) scanDevices();
@@ -451,9 +450,9 @@ QString PlayBackPulseAudio::open(const QString &device, double rate,
     // use the current title / filename or fixed string as stream name
     QString name;
     if (m_info.contains(INF_NAME)) // first choice: title
-	name = m_info.get(INF_NAME).toString().toUtf8().data();
+	name = m_info.get(INF_NAME).toString();
     if (!name.length() && m_info.contains(INF_FILENAME)) // fallback: filename
-	name = m_info.get(INF_FILENAME).toString().toUtf8().data();
+	name = m_info.get(INF_FILENAME).toString();
     if (!name.length()) // last resort: fixed string
 	name = i18n("playback...");
 
@@ -717,7 +716,7 @@ void PlayBackPulseAudio::scanDevices()
     i.m_driver      = QString();
     i.m_card        = -1;
     i.m_sample_spec = s;
-    list[i18n("(use server default)") + "|sound_note"] = i;
+    list[i18n("(Use server default)") + "|sound_note"] = i;
 
     foreach (QString sink, m_device_list.keys()) {
 	QString name        = m_device_list[sink].m_name;
