@@ -34,6 +34,8 @@ class PluginContext;
 class PlayBackDevice;
 class PlayBackDialog;
 
+namespace Kwave { class MixerMatrix; }
+
 class PlayBackPlugin: public Kwave::Plugin, public PlaybackDeviceFactory
 {
     Q_OBJECT
@@ -58,9 +60,12 @@ public:
      * This plugin needs to be persistent!
      * @see Kwave::Plugin::isPersistent()
      */
-    virtual bool isPersistent() { return true; };
+    virtual bool isPersistent() { return true; }
 
-    virtual bool isUnique() { return false; };
+    virtual bool isUnique() { return false; }
+
+    /** this plugin can be interrupted at any time */
+    virtual bool canClose() { return true; }
 
     /**
      * Does playback in a thread.
@@ -77,6 +82,9 @@ signals:
     /** Emits the current playback position */
     void sigPlaybackPos(sample_index_t pos);
 
+    /** Emitted after a successful seek operation */
+    void sigSeekDone(sample_index_t pos);
+
 public slots:
 
     /**
@@ -89,6 +97,15 @@ public slots:
      */
     void stopDevicePlayBack();
 
+    /**
+     * Seek to a new playback position
+     * @param pos the new position in samples, absolute
+     */
+    void seekTo(sample_index_t pos);
+
+    /** updates the mixer matrix if the track selection has changed */
+    void trackSelectionChanged();
+
     /**
      * Plays a sample sound for testing the playback
      */
@@ -171,7 +188,7 @@ private:
     /** The playback device used for playback */
     PlayBackDevice *m_device;
 
-    /** Mutex for locking acces to the playback device */
+    /** Mutex for locking access to the playback device */
     QMutex m_lock_device;
 
     /** the parameters used for playback */
@@ -186,6 +203,21 @@ private:
     /** End of the selection when playback started */
     unsigned int m_old_last;
 
+    /**
+     * Mutex for locking access to members that control the playback
+     * loop, like m_should_seek, m_seek_pos and m_mixer
+     */
+    QMutex m_lock_playback;
+
+    /** if true, m_seek_pos is valid and a seek has been requested */
+    bool m_should_seek;
+
+    /** position to seek to */
+    sample_index_t m_seek_pos;
+
+    /** notification flag, true if the track selection has changed */
+    bool m_track_selection_changed;
+
 };
 
 //*****************************************************************************
