@@ -41,8 +41,9 @@
 #include <ktoolinvocation.h>
 
 #include "libkwave/CompressionType.h"
-#include "libkwave/KwavePlugin.h" // for some helper functions
 #include "libkwave/SampleFormat.h"
+#include "libkwave/Utils.h"
+
 #include "libgui/HMSTimeWidget.h"
 #include "libgui/KwaveFileDialog.h"
 
@@ -597,7 +598,7 @@ void RecordDialog::selectRecordDevice()
     filter += QString("\nadsp*|") + i18n("ALSA record device (adsp*)");
     filter += QString("\n*|") + i18n("Any device (*)");
 
-    KwaveFileDialog dlg(":<kwave_record_device>", filter, this,
+    KwaveFileDialog dlg("kfiledialog:///kwave_record_device", filter, this,
 	true, "file:/dev");
     dlg.setKeepLocation(true);
     dlg.setOperationMode(KFileDialog::Opening);
@@ -971,7 +972,7 @@ void RecordDialog::setState(RecordState state)
     m_state = state;
     switch (state) {
 	case REC_UNINITIALIZED:
-	    state_text = i18n("please check the source device settings...");
+	    state_text = i18n("Please check the source device settings...");
 	    enable_new      = true;
 	    enable_pause    = false;
 	    enable_stop     = false;
@@ -994,7 +995,7 @@ void RecordDialog::setState(RecordState state)
 	    lbl_state->changeItem("", ID_TIME);
 	    break;
 	case REC_BUFFERING:
-	    state_text = i18n("buffering...");
+	    state_text = i18n("Buffering...");
 	    enable_new      = true; /* throw away current FIFO content */
 	    enable_pause    = false;
 	    enable_stop     = true;
@@ -1005,7 +1006,7 @@ void RecordDialog::setState(RecordState state)
 	    pixmaps.push_back(QPixmap(ledlightgreen_xpm));
 	    break;
 	case REC_PRERECORDING:
-	    state_text = i18n("prerecording...");
+	    state_text = i18n("Prerecording...");
 	    enable_new      = false;
 	    enable_pause    = false;
 	    enable_stop     = true;
@@ -1016,7 +1017,7 @@ void RecordDialog::setState(RecordState state)
 	    pixmaps.push_back(QPixmap(ledlightgreen_xpm));
 	    break;
 	case REC_WAITING_FOR_TRIGGER:
-	    state_text = i18n("waiting for trigger...");
+	    state_text = i18n("Waiting for trigger...");
 	    enable_new      = false;
 	    enable_pause    = false;
 	    enable_stop     = true;
@@ -1027,7 +1028,7 @@ void RecordDialog::setState(RecordState state)
 	    pixmaps.push_back(QPixmap(ledlightgreen_xpm));
 	    break;
 	case REC_RECORDING:
-	    state_text = i18n("recording...");
+	    state_text = i18n("Recording...");
 	    enable_new      = false;
 	    enable_pause    = true;
 	    enable_stop     = true;
@@ -1045,7 +1046,7 @@ void RecordDialog::setState(RecordState state)
 	    animation_time = 100;
 	    break;
 	case REC_PAUSED:
-	    state_text = i18n("paused");
+	    state_text = i18n("Paused");
 	    enable_new      = true; /* start again */
 	    enable_pause    = true; /* used for "continue" */
 	    enable_stop     = true;
@@ -1056,7 +1057,7 @@ void RecordDialog::setState(RecordState state)
 	    pixmaps.push_back(QPixmap(ledyellow_xpm));
 	    break;
 	case REC_DONE:
-	    state_text = i18n("done");
+	    state_text = i18n("Done");
 	    enable_new      = true;
 	    enable_pause    = false;
 	    enable_stop     = false;
@@ -1163,11 +1164,13 @@ void RecordDialog::updateBufferState(unsigned int count, unsigned int total)
 		    i18np("and %1 second", "and %1 seconds", s) :
 		    i18np("%1 second", "%1 seconds", s);
 
-		state_text = i18n("waiting for start in %1%2%3%4 ...",
-		                  days, hours, minutes, seconds);
+		state_text = i18nc(
+		    "%1=days; %2=hours; %3=minutes; %4=seconds",
+		    "Waiting for start in %1%2%3%4...",
+		    days, hours, minutes, seconds);
 	    } else {
 		// waiting for trigger...
-		state_text = i18n("waiting for trigger...");
+		state_text = i18n("Waiting for trigger...");
 	    }
 	    lbl_state->changeItem(state_text, ID_STATE);
 
@@ -1181,9 +1184,9 @@ void RecordDialog::updateBufferState(unsigned int count, unsigned int total)
 		double ms = (rate) ?
 		    ((static_cast<double>(m_samples_recorded) / rate) * 1E3)
 		    : 0;
-		txt = " " + i18n("Length: %1", Kwave::Plugin::ms2string(ms)) +
+		txt = " " + i18n("Length: %1", Kwave::ms2string(ms)) +
 		    " " + i18n("(%1 samples)",
-		    Kwave::Plugin::dottedNumber(m_samples_recorded));
+		    Kwave::dottedNumber(m_samples_recorded));
 	    } else txt = "";
 	    break;
 	}
