@@ -53,7 +53,8 @@
 #include "Record-ALSA.h"
 #include "Record-OSS.h"
 
-KWAVE_PLUGIN(RecordPlugin,"record","2.2","Thomas Eschenbacher");
+KWAVE_PLUGIN(RecordPlugin, "record", "2.2",
+             I18N_NOOP("Record"), "Thomas Eschenbacher");
 
 //***************************************************************************
 RecordPlugin::RecordPlugin(const PluginContext &context)
@@ -63,7 +64,6 @@ RecordPlugin::RecordPlugin(const PluginContext &context)
      m_writers(0), m_buffers_recorded(0), m_inhibit_count(0),
      m_trigger_value()
 {
-    i18n("record");
 }
 
 //***************************************************************************
@@ -195,8 +195,10 @@ QStringList *RecordPlugin::setup(QStringList &previous_params)
     m_decoder = 0;
 
     if (m_dialog) {
-	fileInfo().setLength(signalLength());
-	fileInfo().setTracks(m_dialog->params().tracks);
+	FileInfo info(signalManager().metaData());
+	info.setLength(signalLength());
+	info.setTracks(m_dialog->params().tracks);
+	signalManager().setFileInfo(info, false);
 	delete m_dialog;
 	m_dialog = 0;
     }
@@ -380,7 +382,7 @@ void RecordPlugin::setDevice(const QString &device)
 		    reason = i18n(
 			"Kwave was unable to open the device '%1'.\n"\
 			"Maybe your system lacks support for the corresponding "\
-			" hardware or the hardware is not connected.",
+			"hardware or the hardware is not connected.",
 			short_device_name);
 		    break;
 		case -EBUSY:
@@ -393,7 +395,7 @@ void RecordPlugin::setDevice(const QString &device)
 	    }
 
 	    if (reason.length()) Kwave::MessageBox::sorry(parentWidget(),
-		reason, i18n("unable to open the recording device"));
+		reason, i18n("Unable to open the recording device"));
 	}
 
 	m_device_name = QString::null;
@@ -503,8 +505,8 @@ void RecordPlugin::changeSampleRate(double new_rate)
 	if ((static_cast<int>(new_rate) > 0) &&
 	    (static_cast<int>(rate) > 0) &&
 	    (static_cast<int>(new_rate) != static_cast<int>(rate)))
-	    notice(i18n("%1Hz is not supported, "\
-		        "using %2Hz", sr1, sr2));
+	    notice(i18n("%1 Hz is not supported, "\
+		        "using %2 Hz", sr1, sr2));
     }
     m_dialog->setSupportedSampleRates(supported_rates);
 
@@ -519,7 +521,7 @@ void RecordPlugin::changeSampleRate(double new_rate)
 	if ((static_cast<int>(new_rate) > 0) &&
 	    (static_cast<int>(rate) > 0) &&
 	    (static_cast<int>(new_rate) != static_cast<int>(rate)))
-	    notice(i18n("%1Hz failed, using %2Hz", sr1, sr2));
+	    notice(i18n("%1 Hz failed, using %2 Hz", sr1, sr2));
     }
     m_dialog->setSampleRate(rate);
 
@@ -561,7 +563,7 @@ void RecordPlugin::changeCompression(int new_compression)
 	if (compression != new_compression) {
 	    const QString c1(types.name(types.findFromData(new_compression)));
 	    const QString c2(types.name(types.findFromData(compression)));
-	    notice(i18n("compression '%1' not supported, using '%2'",
+	    notice(i18n("Compression '%1' not supported, using '%2'",
                         c1, c2));
 	}
     }
@@ -578,7 +580,7 @@ void RecordPlugin::changeCompression(int new_compression)
 	    const QString c1(types.name(types.findFromData(compression)));
 	    const QString c2(types.name(types.findFromData(
 	                 m_device->compression())));
-	    notice(i18n("compression %1 failed, using %2.", c1 ,c2));
+	    notice(i18n("Compression '%1' failed, using '%2'.", c1 ,c2));
 	}
     }
     m_dialog->setCompression(compression);
@@ -669,7 +671,7 @@ void RecordPlugin::changeSampleFormat(SampleFormat new_format)
 	const QString s1 = sf.name(sf.findFromData(new_format));
 	const QString s2 = sf.name(sf.findFromData(format));
 	if (!(new_format == -1) && !(new_format == format)) {
-	    notice(i18n("sample format '%1' is not supported, "\
+	    notice(i18n("Sample format '%1' is not supported, "\
 		        "using '%2'", s1, s2));
 	}
     }
@@ -685,7 +687,7 @@ void RecordPlugin::changeSampleFormat(SampleFormat new_format)
 	const QString s1 = sf.name(sf.findFromData(new_format));
 	const QString s2 = sf.name(sf.findFromData(format));
 	if (format > 0) notice(
-	    i18n("sample format '%1' failed, using '%2'", s1, s2));
+	    i18n("Sample format '%1' failed, using '%2'", s1, s2));
     }
     m_dialog->setSampleFormat(format);
 }
@@ -884,7 +886,7 @@ void RecordPlugin::startRecording()
 	 */
 	if ((!m_writers) ||
 	    (m_writers->tracks() != tracks) ||
-	    (fileInfo().rate() != rate))
+	    (FileInfo(signalManager().metaData()).rate() != rate))
 	{
 	    // create a new and empty signal
 
@@ -915,13 +917,14 @@ void RecordPlugin::startRecording()
 	}
 
 	// initialize the file information
-	fileInfo().setRate(rate);
-	fileInfo().setBits(bits);
-	fileInfo().setTracks(tracks);
-	fileInfo().set(INF_MIMETYPE, "audio/vnd.wave");
-	fileInfo().set(INF_SAMPLE_FORMAT,
+	FileInfo fileInfo(signalManager().metaData());
+	fileInfo.setRate(rate);
+	fileInfo.setBits(bits);
+	fileInfo.setTracks(tracks);
+	fileInfo.set(INF_MIMETYPE, "audio/vnd.wave");
+	fileInfo.set(INF_SAMPLE_FORMAT,
 	    m_dialog->params().sample_format.toInt());
-	fileInfo().set(INF_COMPRESSION, m_dialog->params().compression);
+	fileInfo.set(INF_COMPRESSION, m_dialog->params().compression);
 
 	// add our Kwave Software tag
 	const KAboutData *about_data =
@@ -932,7 +935,7 @@ void RecordPlugin::startRecording()
 			    i18n(KDE_VERSION_STRING);
 	qDebug("adding software tag: '%s'",
 		software.toLocal8Bit().data());
-	fileInfo().set(INF_SOFTWARE, software);
+	fileInfo.set(INF_SOFTWARE, software);
 
 	// add a date tag, ISO format
 	QDate now(QDate::currentDate());
@@ -940,7 +943,8 @@ void RecordPlugin::startRecording()
 	date = date.sprintf("%04d-%02d-%02d",
 		now.year(), now.month(), now.day());
 	QVariant value = date.toUtf8();
-	fileInfo().set(INF_CREATION_DATE, value);
+	fileInfo.set(INF_CREATION_DATE, value);
+	signalManager().setFileInfo(fileInfo, false);
     }
 
     // now the recording can be considered to be started
@@ -961,18 +965,19 @@ void RecordPlugin::recordStopped(int reason)
 	                       "number and/or size of the record buffers.");
 	    break;
 	case -EBUSY:
-	    description = i18n("The recording device seems to be busy!");
+	    description = i18n("The recording device seems to be busy.");
 	    break;
 	default:
-	    description = i18n("Reading from the recording device failed, "\
-	                       "error number = %1 (%2)", -reason,
+	    description = i18n("Reading from the recording device failed. "\
+	                       "Error number = %1 (%2)", -reason,
 			       QString::fromLocal8Bit(strerror(-reason)));
     }
     Kwave::MessageBox::error(m_dialog, description);
 
     if (m_writers) m_writers->flush();
-    qDebug("RecordPlugin::recordStopped(): last=%u",
-           (m_writers) ? m_writers->last() : 0);
+    qDebug("RecordPlugin::recordStopped(): last=%lu",
+	   static_cast<unsigned long int>(
+           (m_writers) ? m_writers->last() : 0));
 
     // flush away all prerecording buffers
     m_prerecording_queue.clear();
