@@ -38,6 +38,7 @@
 
 #include "libkwave/KwavePlugin.h"
 #include "libkwave/WindowFunction.h"
+#include "libkwave/Utils.h"
 
 #include "SonagramDialog.h"
 
@@ -105,7 +106,7 @@ void SonagramDialog::parameters(QStringList &list)
     list.clear();
 
     // parameter #0: number of fft points
-    param = pointbox ? pointbox->currentText() : QString(0);
+    param = pointbox ? pointbox->currentText() : QString();
     list.append(param);
 
     // parameter #1: index of the window function
@@ -140,10 +141,10 @@ void SonagramDialog::setPoints(int points)
     text.setNum(points);
     pointbox->setEditText(text);
 
-    windowlabel->setText(i18n("( resulting window size: %1 )",
-	Kwave::Plugin::ms2string(points * 1.0E3 / m_rate)));
+    windowlabel->setText(i18n("(resulting window size: %1)",
+	Kwave::ms2string(points * 1.0E3 / m_rate)));
 
-    bitmaplabel->setText(i18n("size of bitmap: %1x%2",
+    bitmaplabel->setText(i18n("Size of bitmap: %1x%2",
 	(m_length / points) + 1,
 	points/2));
 }
